@@ -1,9 +1,19 @@
+"""Abstract Checkpoint class
+"""
 # main imports
 import os
 import logging
 
 
 class Checkpoint():
+    """
+    Local Search used as exploitation optimization algorithm
+
+    Attributes:
+        algo: {Algorithm} -- main algorithm instance reference
+        every: {int} -- checkpoint frequency used (based on number of evaluations)
+        filepath: {str} -- file path where checkpoints will be saved
+    """
     def __init__(self, _algo, _every, _filepath):
         self.algo = _algo
         self.every = _every
